@@ -224,11 +224,13 @@ def _buildPluginDictionary(folder, element, hubName):
 			pass
 
 	parmsDict = {}
-	parms = paramsString.split("\n")
-	for parmline in parms:
-		if parmline: # in case of any blank lines in the params field
-			n,v = parmline.split("=", 1)
-			parmsDict[n] = v
+
+        if paramsString:
+		parms = paramsString.split("\n")
+		for parmline in parms:
+			if parmline: # in case of any blank lines in the params field
+				n,v = parmline.split("=", 1)
+				parmsDict[n] = v
 
 	return parmsDict
 	
