@@ -807,4 +807,55 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 		if verbose:
 			print "syncing user '" + duser.username + "' to ldap"
 		_syncuser(duser.username, hubname, syncattributes)
-	
+
+
+def updateuser(username, hubname = "", fname="", mname="", lname="", email="", homedir="" ):
+
+	if not hubname:
+		hubname = hubzero.config.webconfig.getDefaultSite()
+
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	uidNumber = _getUserID(db, username)
+
+	_update_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, email, '', '', '', '', '', '', homedir) 
+
+	if homedir:  _update_ldap_user_attribue(username, 'homeDirectory', homedir)
+
+
+
+def _update_ldap_user_attribue(uid, attributename, attributevalue):
+
+        hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
+        hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
+        hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
+        ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
+        l = ldap.initialize(ldapServer)
+        l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
+
+        dn = "uid=" + uid + ",ou=users," + hubLDAPBaseDN
+        attrs = [ (ldap.MOD_REPLACE, attributename, attributevalue) ]
+        l.modify_s(dn, attrs)
+
+
+def _update_jos_xprofiles(db, hubname, uid, fname='', mname='', lname='',  email='', pw='', joomlagid = '', joomlagidNumber = '', gid = '', gidNumber = '', loginShell = '', homeDir = ''):
+
+	nvlist = {} 
+
+	if fname : nvlist['givenName'] = fname
+	if lname : nvlist['surname'] = lname
+	if email : nvlist['email'] = email
+	if homeDir : nvlist['homeDirectory'] = homeDir
+
+	sql = "UPDATE `jos_xprofiles`" 
+	sql += " SET " + "=%s, ".join(nvlist.keys()) + "=%s"
+	sql += " WHERE uidNumber = %s "
+
+	values = nvlist.values()
+	values.append(uid)
+
+	db.query_rowcount(sql, values)
+
